.. image:: https://img.shields.io/pypi/v/pytest-black-multipy.svg
   :target: https://pypi.org/project/pytest-black-multipy

.. image:: https://img.shields.io/pypi/pyversions/pytest-black-multipy.svg

.. image:: https://img.shields.io/travis/jaraco/pytest-black-multipy/master.svg
   :target: https://travis-ci.org/jaraco/pytest-black-multipy

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/pytest-black-multipy/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/pytest-black-multipy/branch/master

.. .. image:: https://readthedocs.org/projects/pytest-black-multipy/badge/?version=latest
..    :target: https://pytest-black-multipy.readthedocs.io/en/latest/?badge=latest


A wrapper around `pytest-black <https://pypi.org/project/pytest-black>`_
to allow projects on older Python versions to use the ``--black`` paremeter.
